==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azuresphere/kotlin/inputs/ListCatalogDevicesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azuresphere.kotlin.inputs

import com.pulumi.azurenative.azuresphere.inputs.ListCatalogDevicesPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property catalogName Name of catalog
 * @property filter Filter the result list using the given expression
 * @property maxpagesize The maximum number of result items per page.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property skip The number of result items to skip.
 * @property top The number of result items to return.
 */
public data class ListCatalogDevicesPlainArgs(
    public val catalogName: String,
    public val filter: String? = null,
    public val maxpagesize: Int? = null,
    public val resourceGroupName: String,
    public val skip: Int? = null,
    public val top: Int? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azuresphere.inputs.ListCatalogDevicesPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.azuresphere.inputs.ListCatalogDevicesPlainArgs =
        com.pulumi.azurenative.azuresphere.inputs.ListCatalogDevicesPlainArgs.builder()
            .catalogName(catalogName.let({ args0 -> args0 }))
            .filter(filter?.let({ args0 -> args0 }))
            .maxpagesize(maxpagesize?.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .skip(skip?.let({ args0 -> args0 }))
            .top(top?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListCatalogDevicesPlainArgs].
 */
@PulumiTagMarker
public class ListCatalogDevicesPlainArgsBuilder internal constructor() {
    private var catalogName: String? = null

    private var filter: String? = null

    private var maxpagesize: Int? = null

    private var resourceGroupName: String? = null

    private var skip: Int? = null

    private var top: Int? = null

    /**
     * @param value Name of catalog
     */
    @JvmName("kbcpulhfkfpabdjt")
    public suspend fun catalogName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.catalogName = mapped
    }

    /**
     * @param value Filter the result list using the given expression
     */
    @JvmName("dmwkwkchhejmcwlk")
    public suspend fun filter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.filter = mapped
    }

    /**
     * @param value The maximum number of result items per page.
     */
    @JvmName("ssvauqosdihkwxyf")
    public suspend fun maxpagesize(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.maxpagesize = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("xglnndvhsyoubinb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The number of result items to skip.
     */
    @JvmName("wpvixybyfbqxtttx")
    public suspend fun skip(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.skip = mapped
    }

    /**
     * @param value The number of result items to return.
     */
    @JvmName("lcftwspsdxlmwfbr")
    public suspend fun top(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.top = mapped
    }

    internal fun build(): ListCatalogDevicesPlainArgs = ListCatalogDevicesPlainArgs(
        catalogName = catalogName ?: throw PulumiNullFieldException("catalogName"),
        filter = filter,
        maxpagesize = maxpagesize,
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        skip = skip,
        top = top,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azuresphere/kotlin/inputs/ListCatalogDevicesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azuresphere.kotlin.inputs

import com.pulumi.azurenative.azuresphere.inputs.ListCatalogDevicesPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property catalogName Name of catalog
 * @property filter Filter the result list using the given expression
 * @property maxpagesize The maximum number of result items per page.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property skip The number of result items to skip.
 * @property top The number of result items to return.
 */
public data class ListCatalogDevicesPlainArgs(
    public val catalogName: String,
    public val filter: String? = null,
    public val maxpagesize: Int? = null,
    public val resourceGroupName: String,
    public val skip: Int? = null,
    public val top: Int? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azuresphere.inputs.ListCatalogDevicesPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.azuresphere.inputs.ListCatalogDevicesPlainArgs =
        com.pulumi.azurenative.azuresphere.inputs.ListCatalogDevicesPlainArgs.builder()
            .catalogName(catalogName.let({ args0 -> args0 }))
            .filter(filter?.let({ args0 -> args0 }))
            .maxpagesize(maxpagesize?.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .skip(skip?.let({ args0 -> args0 }))
            .top(top?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListCatalogDevicesPlainArgs].
 */
@PulumiTagMarker
public class ListCatalogDevicesPlainArgsBuilder internal constructor() {
    private var catalogName: String? = null

    private var filter: String? = null

    private var maxpagesize: Int? = null

    private var resourceGroupName: String? = null

    private var skip: Int? = null

    private var top: Int? = null

    /**
     * @param value Name of catalog
     */
    @JvmName("kynswhtvejnelrcu")
    public suspend fun catalogName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.catalogName = mapped
    }

    /**
     * @param value Filter the result list using the given expression
     */
    @JvmName("nubpiculdynohbcv")
    public suspend fun filter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.filter = mapped
    }

    /**
     * @param value The maximum number of result items per page.
     */
    @JvmName("kdjypitqggjixpca")
    public suspend fun maxpagesize(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.maxpagesize = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("chqywuqplehjmrna")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The number of result items to skip.
     */
    @JvmName("iamcqckgyjdjoouh")
    public suspend fun skip(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.skip = mapped
    }

    /**
     * @param value The number of result items to return.
     */
    @JvmName("fpwnktmxqlsllbmh")
    public suspend fun top(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.top = mapped
    }

    internal fun build(): ListCatalogDevicesPlainArgs = ListCatalogDevicesPlainArgs(
        catalogName = catalogName ?: throw PulumiNullFieldException("catalogName"),
        filter = filter,
        maxpagesize = maxpagesize,
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        skip = skip,
        top = top,
    )
}
